@@ -25,11 +25,13 @@ use crate::v0;
 use crate::Location;
 use crate::Output;
 
+use aws::AwsCredentials;
 use azure::AzureCredentials;
 use config::Config;
 use helper::{AddLocation, RegisterCluster};
 use print::{ClusterAndStates, Print, StateAndClusters};
 
+mod aws;
 mod azure;
 mod config;
 mod events;
@@ -200,6 +202,9 @@ enum Command {
         #[structopt(help = "Cleanup grace time out", long, default_value = "600s")]
         cleanup_grace: String,
 
+        #[structopt(flatten)]
+        aws: AwsCredentials,
+
         #[structopt(flatten)]
         azure: AzureCredentials,
     },
@@ -249,6 +254,8 @@ enum Command {
         )]
         namespace: String,
         #[structopt(flatten)]
+        aws: AwsCredentials,
+        #[structopt(flatten)]
         azure: AzureCredentials,
         #[structopt(
             help = "Kubeconfig context to use for updating cluster",
@@ -682,6 +689,7 @@ impl Cli {
                 skip_helm,
                 provider,
                 cleanup_grace,
+                aws,
                 azure,
             } => {
                 let (kubectls, register_cluster) = if non_interactive {
@@ -698,6 +706,7 @@ impl Cli {
                             skip_helm,
                             provider,
                             cleanup_grace,
+                            aws,
                             azure,
                         )
                         .await?
@@ -715,6 +724,7 @@ impl Cli {
                             skip_helm,
                             provider,
                             cleanup_grace,
+                            aws,
                             azure,
                         )
                         .await?
@@ -742,6 +752,7 @@ impl Cli {
             Command::UpdateCluster {
                 name,
                 namespace,
+                aws,
                 azure,
                 context,
             } => {
@@ -752,7 +763,7 @@ impl Cli {
                 // })?;
                 // let kubectl = k8s::Kubectl::with_context_or_current(None)?;
                 statehub
-                    .update_cluster(name, context, namespace, azure)
+                    .update_cluster(name, context, namespace, aws, azure)
                     .await
             }
             Command::ListClusters => statehub.list_clusters().await,
@@ -1024,6 +1035,7 @@ impl StateHub {
         name: Option<v0::ClusterName>,
         context: Option<String>,
         namespace: String,
+        aws: AwsCredentials,
         azure: AzureCredentials,
     ) -> anyhow::Result<()> {
         let names = name.into_iter().collect();
@@ -1037,8 +1049,8 @@ impl StateHub {
                 azure
             ))?;
             let azure = Some(&azure);
-            let aws = None;
-            self.setup_credentials_helper(&kubectl, &namespace, azure, aws)
+            let aws = Some(&aws);
+            self.setup_credentials_helper(&kubectl, &namespace, aws, azure)
                 .await?;
         }
         Ok(())
