@@ -25,6 +25,7 @@ pub use self::cluster::{
     CreateClusterDto, Provider,
 };
 pub use self::error::{Error, Permission, StatehubError};
+pub use self::events::{Report, Reporter};
 pub use self::gcp::GcpRegion;
 pub use self::helm::Helm;
 pub use self::login::Login;
@@ -42,6 +43,7 @@ mod aws;
 mod azure;
 mod cluster;
 mod error;
+mod events;
 mod gcp;
 mod helm;
 mod login;
